
import missing_module
from missing_module import missing_name
import missing_package1.missing_module1
from missing_package2 import missing_module2
from missing_package3.missing_module3 import missing_name

@missing_name
def decoratedFunction():
  """decoratedFunction docstring"""
  return None

class TestAutodoc(object):
    """TestAutodoc docstring."""
    @missing_name
    def decoratedMethod(self):
        """TestAutodoc::decoratedMethod docstring"""
        return None



# -*- coding: utf-8 -*-
"""
    Sphinx test suite utilities
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~

    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

import os
import tempfile

import pytest

from sphinx.testing.path import path


__all__ = [
    'rootdir', 'tempdir',
    'skip_unless_importable',
]


rootdir = path(__file__).abspath().parent
if 'SPHINX_TEST_TEMPDIR' in os.environ:
    tempdir = path(os.environ['SPHINX_TEST_TEMPDIR']).abspath()
else:
    tempdir = path(tempfile.mkdtemp()).abspath()


def skip_unless_importable(module, msg=None):
    """Decorator to skip test if module is not importable."""
    try:
        __import__(module)
    except ImportError:
        return pytest.mark.skipif(True, reason=(msg or 'conditional skip'))
    else:
        return pytest.mark.skipif(False, reason=(msg or 'conditional skip'))
